#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hookup
version:              0.8
visibility:           public
id:                   hookup-0.8-JVNUnSIsLjBUJkgqr5nGD
key:                  hookup-0.8-JVNUnSIsLjBUJkgqr5nGD
license:              ISC
copyright:            2016-2020 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:
    Abstraction over creating network connections with SOCKS5 and TLS

description:
    This package provides an abstraction for communicating with line-oriented
    network services while abstracting over the use of SOCKS5 and TLS (via OpenSSL)

category:             Network
abi:                  4e762beb69620bd37cd448b39d7df191
exposed:              True
exposed-modules:      Hookup Hookup.OpenSSL
hidden-modules:       Hookup.Socks5 Hookup.Concurrent
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hookup-0.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hookup-0.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hookup-0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hookup
hs-libraries:         HShookup-0.8-JVNUnSIsLjBUJkgqr5nGD
depends:
    HsOpenSSL-0.11.7.9-DT5hmbGM9IAKKAxevMGtcw
    HsOpenSSL-x509-system-0.1.0.4-GMjq0drrb5yHinRzVZrFa7
    async-2.2.6-AoIAnpP1AE52EgJKBLwe0w
    attoparsec-0.14.4-AJVRZfhVOVzJGMVFtBGw8r base-4.18.2.1
    bytestring-0.11.5.3 network-3.1.4.0-FxgQMUnc8In23QMgSfNDtL
    stm-2.5.1.0

haddock-interfaces:   /usr/share/doc/haskell-hookup/html/hookup.haddock
haddock-html:         /usr/share/doc/haskell-hookup/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

